<!DOCTYPE html>
<!--[if lt IE 7 ]><html class="ie ie6" lang="de"><![endif]-->
<!--[if IE 7 ]><html class="ie ie7" lang="de"><![endif]-->
<!--[if IE 8 ]><html class="ie ie8" lang="de"><![endif]-->
<!--[if (gte IE 9)|!(IE)]><!-->
<html lang="de"><!--<![endif]-->
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="edge">
    <meta http-equiv="imagetoolbar" content="false">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <link href="https://cdn.solarlux.com/bs-sl/2/css/bootstrap.css" rel="stylesheet" type="text/css"/>

    <!--[if lt IE 9]> <script src="https://html5shiv.googlecode.com/svn/trunk/html5.js"></script> <![endif]-->
    <meta name="application-name" content="Portal"/>
    <meta name="author" content="Solarlux GmbH"/>
    <title>Portal</title>
    <meta name="description" content=""/>
    <meta name="keywords" content=""/>
    <meta name="dcterms.title" content="Portal"/>
    <meta name="dcterms.description" content=""/>
    <meta property="og:title" content="Portal"/>
    <meta property="og:description" content=""/>
    <meta name="dcterms.contributor" content="Solarlux GmbH"/>
    <meta name="dcterms.creator" content="Solarlux GmbH"/>
    <meta name="dcterms.publisher" content="Solarlux GmbH"/>
    <meta name="dcterms.rights" content="Solarlux GmbH"/>
    <meta name="robots" content="index, follow">
    <script async src="https://www.googletagmanager.com/gtag/js?id=UA-1431662-79"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }

        gtag('js', new Date());
        gtag('config', 'UA-1431662-79');
    </script>

    <!-- Favicons -->
    <link rel="shortcut icon" href="#siterelpath#favicon.ico">
    <link rel="apple-touch-icon" sizes="32x32" href="https://www.solarlux.com/img/favicon-32x32.png">
    <link rel="apple-touch-icon" sizes="144x144" href="https://my.solarlux.com/img/favicon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="https://www.solarlux.com/img/favicon-152x152.png">
    <link rel="shortcut icon" href="https://www.solarlux.com/favicon.ico">
    <link rel="icon" sizes="16x16" href="https://www.solarlux.com/img/favicon-16x16.png" type="image/png">
    <link rel="icon" sizes="32x32" href="https://www.solarlux.com/img/favicon-32x32.png" type="image/png">
    <link rel="apple-touch-icon" sizes="57x57" href="https://www.solarlux.com/img/favicon-57x57.png" type="image/png">
    <link rel="apple-touch-icon" sizes="60x60" href="https://www.solarlux.com/img/favicon-60x60.png" type="image/png">
    <link rel="apple-touch-icon" sizes="72x72" href="https://www.solarlux.com/img/favicon-72x72.png" type="image/png">
    <link rel="apple-touch-icon" sizes="76x76" href="https://www.solarlux.com/img/favicon-76x76.png" type="image/png">
    <link rel="apple-touch-icon" sizes="144x144" href="https://www.solarlux.com/img/favicon-144x144.png"
          type="image/png">
    <link rel="apple-touch-icon" sizes="152x152" href="https://www.solarlux.com/img/favicon-152x152.png"
          type="image/png">
    <link rel="manifest" href="https://www.solarlux.com/manifest.json">

    {% block styles %}

    {% endblock %}

    <script type="text/javascript" src="https://cdn.solarlux.com/bs-sl/2/js/bootstrap-header.js"></script>

</head>
<body class="{% block bodyclass %} no-js standardseite hasSidebar hasAside {% endblock %}">
<header class="fixed-top">
    <nav class="navbar navbar-toggleable-sm">
        <div class="d-flex justify-content-between w-100">
            <div class="hamburger-btn align-self-center d-md-none">
                <ul class="navbar-nav flex-row">
                    <li class="nav-item hidden-xl-up"><a href="#" class="nav-link mb-0" data-toggle="offcanvas"
                                                         data-target="#sidebar" aria-controls="sidebar"
                                                         aria-expanded="true" aria-label="Toggle navigation"> <i
                            class="sl-icon sl-menu-hamburger icon-2x" aria-hidden="true"></i> </a></li>
                </ul>
            </div>
            <a class="logo align-self-center" href="/"> <img
                    src="https://cdn.solarlux.com/bs-sl/2/img/logo_my_solarlux_w.svg" width="130" alt="mySolarlux"> </a>
                    <label id="my_app_name" class="my_app_name"></label>
            <div class="help-nav align-self-center">
                <ul class="navbar-nav flex-row" id="headerIcons"></ul>
            </div>
        </div>
    </nav>
</header>

<div class="header">
    <nav class="navbar navbar-toggleable-sm">
        <ul class="navbar-nav flex-row">
            <li class="nav-item"><a class="nav-link mb-0"><i class="sl-icon sl-logout"></i></a></li>
        </ul>
    </nav>
</div>

<div class="master container-fluid">
    <div class="row h-100">

        <nav id="sidebar" class="navbar-toggleable-md fixed-top sidebar" role="tablist" aria-multiselectable="true">
            <div class="header">
                <nav class="navbar navbar-toggleable-sm">
                    <ul class="navbar-nav flex-row">
                        <li class="nav-item"><a class="nav-link px-1 mb-0"><i class="sl-icon sl-logout"></i></a></li>
                    </ul>
                </nav>
            </div>
            <ul class="nav collapse flex-column" id="navMain"></ul>
        </nav>

        <main class="col">
            <div class="row topContent">
                <div class="col-12">

                    {% block content %}



                    {% endblock %}

                </div>
            </div>

        </main>

        <aside id="aside" class="navbar-toggleable-md fixed-top fixed-top-right">
            <div class="header">
                <nav class="navbar navbar-toggleable-sm">
                    <ul class="navbar-nav flex-row">
                        <li class="nav-item"><a class="nav-link mb-0"><i class="sl-icon sl-logout"></i></a></li>
                    </ul>
                </nav>
            </div>

            <div id="user-info" class="card text-center">
                <div class="aside-photo-icon-container avatar">
                    <i class="sl-icon sl-user icon-5x" id="user-generic-icon"></i>
                    <div class="crop round-crop d-none">
                        <img id="user-profile-image" width="100" height="100" src="">
                    </div>
                </div>
                <div class="card-body">
                    <h4 class="card-title d-none"></h4>
                    <p class="card-text d-none"></p>
                    <a id="profile-edit-link" href="#" class="btn btn-primary"></a>
                </div>
            </div>
            <br>
            <div id="contact-info" class="card text-center d-none">
                <div class="aside-photo-icon-container avatar">
                    <i class="sl-icon sl-user icon-5x" id="account-manager-generic-icon"></i>
                    <div class="crop round-crop d-none">
                        <img id="contact-person-profile-image" width="100" height="100" src="">
                    </div>
                </div>
                <div class="card-body">
                    <p class="card-text contact-person"></p>
                    <p class="card-text">
                        <a href="" class="contact-person-number-link d-none">
                            <i class="sl-icon sl-phone-alt"></i> <span class="contact-person-number"></span>
                        </a>
                        <br>
                        <a href="" class="contact-person-email-link d-none">
                            <i class="sl-icon sl-envelope"></i> <span class="contact-person-email"></span>
                        </a>
                    </p>
                </div>
            </div>

        </aside>

    </div>
</div>
<div class="footer">
    <nav class="navbar navbar-toggleable-sm bg-inverse flex-column flex-md-row">
        <ul class="navbar-nav flex-column flex-md-row" aria-labelledby="navbarDropdownMenuLink">
            <li class="nav-item"><a class="nav-link active" href="#">&nbsp;</a></li>
        </ul>
    </nav>
</div>
<footer class="footer">
    <nav class="navbar navbar-toggleable-sm bg-inverse flex-column flex-md-row">
        <ul class="navbar-nav flex-column flex-md-row" aria-labelledby="navbarDropdownMenuLink" id="navFooter"></ul>
    </nav>
</footer>

<script type="text/javascript" src="https://cdn.solarlux.com/jquery/3/jquery.min.js"></script>
<script type="text/javascript" src="https://cdn.solarlux.com/bs-sl/2/js/bootstrap.js"></script>
{% block scripts %}
{% endblock %}

<div class="bp" style="overflow: hidden; height: 1px;"></div>
</body>
</html>
